define(['exports'], (function (exports) { 'use strict';

  /**
   * Documentation node kinds
   */
  exports.NodeKind = void 0;
  (function (NodeKind) {
      NodeKind[NodeKind["Table"] = 1] = "Table";
      NodeKind[NodeKind["TableRow"] = 2] = "TableRow";
      NodeKind[NodeKind["TableCell"] = 3] = "TableCell";
      NodeKind[NodeKind["Heading"] = 4] = "Heading";
      NodeKind[NodeKind["Paragraph"] = 5] = "Paragraph";
      NodeKind[NodeKind["Text"] = 6] = "Text";
      NodeKind[NodeKind["Bold"] = 7] = "Bold";
      NodeKind[NodeKind["Emphasis"] = 8] = "Emphasis";
      NodeKind[NodeKind["Link"] = 9] = "Link";
      NodeKind[NodeKind["Code"] = 10] = "Code";
      NodeKind[NodeKind["InlineCode"] = 11] = "InlineCode";
      NodeKind[NodeKind["Block"] = 12] = "Block";
      NodeKind[NodeKind["Collapsible"] = 13] = "Collapsible";
  })(exports.NodeKind || (exports.NodeKind = {}));
  /**
   * Node with children type guard predicate
   */
  const isNodeWithChildren = (node) => {
      return (node.kind === exports.NodeKind.Table ||
          node.kind === exports.NodeKind.TableRow ||
          node.kind === exports.NodeKind.TableCell ||
          node.kind === exports.NodeKind.Heading ||
          node.kind === exports.NodeKind.Paragraph ||
          node.kind === exports.NodeKind.Bold ||
          node.kind === exports.NodeKind.Emphasis ||
          node.kind === exports.NodeKind.Link ||
          node.kind === exports.NodeKind.Collapsible ||
          node.kind === exports.NodeKind.Block);
  };
  /**
   * Node with value type guard predicate
   */
  const isNodeWithValue = (node) => {
      return (node.kind === exports.NodeKind.Text ||
          node.kind === exports.NodeKind.InlineCode ||
          node.kind === exports.NodeKind.Code);
  };
  /**
   * TableNode type guard predicate
   */
  const isTableNode = (node) => {
      return node.kind === exports.NodeKind.Table;
  };
  /**
   * TableRowNode type guard predicate
   */
  const isTableRowNode = (node) => {
      return node.kind === exports.NodeKind.TableRow;
  };
  /**
   * TableCellNode type guard predicate
   */
  const isTableCellNode = (node) => {
      return node.kind === exports.NodeKind.TableCell;
  };
  /**
   * HeadingNode type guard predicate
   */
  const isHeadingNode = (node) => {
      return node.kind === exports.NodeKind.Heading;
  };
  /**
   * ParagraphNode type guard predicate
   */
  const isParagraphNode = (node) => {
      return node.kind === exports.NodeKind.Paragraph;
  };
  /**
   * TextNode type guard predicate
   */
  const isTextNode = (node) => {
      return node.kind === exports.NodeKind.Text;
  };
  /**
   * BoldNode type guard predicate
   */
  const isBoldNode = (node) => {
      return node.kind === exports.NodeKind.Bold;
  };
  /**
   * EmphasisNode type guard predicate
   */
  const isEmphasisNode = (node) => {
      return node.kind === exports.NodeKind.Emphasis;
  };
  /**
   * LinkNode type guard predicate
   */
  const isLinkNode = (node) => {
      return node.kind === exports.NodeKind.Link;
  };
  /**
   * CodeNode type guard predicate
   */
  const isCodeNode = (node) => {
      return node.kind === exports.NodeKind.Code;
  };
  /**
   * InlineCodeNode type guard predicate
   */
  const isInlineCodeNode = (node) => {
      return node.kind === exports.NodeKind.InlineCode;
  };
  /**
   * BlockNode type guard predicate
   */
  const isBlockNode = (node) => {
      return node.kind === exports.NodeKind.Block;
  };
  /**
   * CollapsibleNode type guard predicate
   */
  const isCollapsibleNode = (node) => {
      return node.kind === exports.NodeKind.Collapsible;
  };

  exports.isBlockNode = isBlockNode;
  exports.isBoldNode = isBoldNode;
  exports.isCodeNode = isCodeNode;
  exports.isCollapsibleNode = isCollapsibleNode;
  exports.isEmphasisNode = isEmphasisNode;
  exports.isHeadingNode = isHeadingNode;
  exports.isInlineCodeNode = isInlineCodeNode;
  exports.isLinkNode = isLinkNode;
  exports.isNodeWithChildren = isNodeWithChildren;
  exports.isNodeWithValue = isNodeWithValue;
  exports.isParagraphNode = isParagraphNode;
  exports.isTableCellNode = isTableCellNode;
  exports.isTableNode = isTableNode;
  exports.isTableRowNode = isTableRowNode;
  exports.isTextNode = isTextNode;

  Object.defineProperty(exports, '__esModule', { value: true });

}));
